summaryrefslogtreecommitdiff
path: root/subversion/include/private/svn_magic.h
diff options
context:
space:
mode:
Diffstat (limited to 'subversion/include/private/svn_magic.h')
-rw-r--r--subversion/include/private/svn_magic.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/subversion/include/private/svn_magic.h b/subversion/include/private/svn_magic.h
index b057e56..2e5fafd 100644
--- a/subversion/include/private/svn_magic.h
+++ b/subversion/include/private/svn_magic.h
@@ -30,14 +30,16 @@
/* An opaque struct that wraps a libmagic cookie. */
typedef struct svn_magic__cookie_t svn_magic__cookie_t;
/* This routine initialises libmagic.
* Upon success a new *MAGIC_COOKIE is allocated in RESULT_POOL.
* On failure *MAGIC_COOKIE is set to NULL.
* All resources used by libmagic are freed by a cleanup handler
* installed on RESULT_POOL, i.e. *MAGIC_COOKIE becomes invalid when
* the pool is cleared! */
-void
+svn_error_t *
svn_magic__init(svn_magic__cookie_t **magic_cookie,
+ apr_hash_t *config,
apr_pool_t *result_pool);
/* Detect the mime-type of the file at LOCAL_ABSPATH using MAGIC_COOKIE.
@@ -30,14 +30,16 @@
/* An opaque struct that wraps a libmagic cookie. */
typedef struct svn_magic__cookie_t svn_magic__cookie_t;
-/* This routine initialises libmagic.
+/* This routine initialises libmagic. CONFIG is a config hash and
+ * may be NULL.
* Upon success a new *MAGIC_COOKIE is allocated in RESULT_POOL.
* On failure *MAGIC_COOKIE is set to NULL.